==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-filter/lib/hilbert_fc_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_FILTER_HILBERT_FC_IMPL_H
#define INCLUDED_FILTER_HILBERT_FC_IMPL_H

#include <filter/hilbert_fc.h>
#include <filter/fir_filter.h>
#include <gr_types.h>

namespace gr {
  namespace filter {

    class FILTER_API hilbert_fc_impl : public hilbert_fc
    {
    private:
      unsigned int            d_ntaps;
      kernel::fir_filter_fff *d_hilb;

    public:
      hilbert_fc_impl(unsigned int ntaps);
      
      ~hilbert_fc_impl();
      
      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);
    };

  } /* namespace filter */
} /* namespace gr */

#endif /* INCLUDED_FILTER_HILBERT_FC_IMPL_H */

==> gnuradio_3.7.1.orig.tar.gz: gnuradio-3.7.1/gr-filter/lib/hilbert_fc_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004,2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_FILTER_HILBERT_FC_IMPL_H
#define INCLUDED_FILTER_HILBERT_FC_IMPL_H

#include <gnuradio/filter/hilbert_fc.h>
#include <gnuradio/filter/fir_filter.h>
#include <gnuradio/types.h>

namespace gr {
  namespace filter {

    class FILTER_API hilbert_fc_impl : public hilbert_fc
    {
    private:
      unsigned int            d_ntaps;
      kernel::fir_filter_fff *d_hilb;

    public:
      hilbert_fc_impl(unsigned int ntaps);
      
      ~hilbert_fc_impl();
      
      int work(int noutput_items,
	       gr_vector_const_void_star &input_items,
	       gr_vector_void_star &output_items);
    };

  } /* namespace filter */
} /* namespace gr */

#endif /* INCLUDED_FILTER_HILBERT_FC_IMPL_H */
